@@ -6,6 +6,8 @@ This module contains a read-only model of the :term:`SKOS` specification.
 .. versionadded:: 0.2.0
 '''
 
+from __future__ import unicode_literals
+
 import collections
 
 
@@ -29,6 +31,11 @@ class Label:
     The language the label is in (eg. `en`, `en-US`, `nl`, `nl-BE`).
     '''
 
+    valid_types=['prefLabel', 'altLabel', 'hiddenLabel']
+    '''
+    The valid types for a label
+    '''
+
     def __init__(self, label, type="prefLabel", language=None):
         self.label = label
         self.type = type
@@ -51,7 +58,7 @@ class Label:
 
         :param string type: The type to be checked.
         '''
-        return type in ['prefLabel', 'altLabel', 'hiddenLabel']
+        return type in Label.valid_types
 
 
 class Note:
@@ -64,7 +71,7 @@ class Note:
 
     type = "note"
     '''
-    The type of this note ( `note`, `defintion`, `scopeNote`, ...).
+    The type of this note ( `note`, `definition`, `scopeNote`, ...).
     '''
 
     language = None
@@ -72,6 +79,19 @@ class Note:
     The language the label is in (eg. `en`, `en-US`, `nl`, `nl-BE`).
     '''
 
+    valid_types=[
+            'note',
+            'changeNote',
+            'definition',
+            'editorialNote',
+            'example',
+            'historyNote',
+            'scopeNote'
+        ]
+    '''
+    The valid types for a note
+    '''
+
     def __init__(self, note, type="note", language=None):
         self.note = note
         self.type = type
@@ -90,24 +110,25 @@ class Note:
 
         :param string type: The type to be checked.
         '''
-        return type in [
-            'note',
-            'changeNote',
-            'definition',
-            'editorialNote',
-            'example',
-            'historyNote',
-            'scopeNote'
-        ]
+        return type in Note.valid_types
 
 
 class ConceptScheme:
     '''
     A :term:`SKOS` ConceptScheme.
+
+    :param string uri: A :term:`URI` for this conceptscheme.
+    :param list labels: A list of :class:`skosprovider.skos.Label` instances.
     '''
 
-    def __init__(self, id, labels=[]):
-        self.id = id
+    uri = None
+    '''A :term:`URI` for this conceptscheme.'''
+
+    labels = []
+    '''A list of labels for this conceptscheme.'''
+
+    def __init__(self, uri, labels=[]):
+        self.uri = uri
         self.labels = labels
 
     def label(self, language='any'):
@@ -128,15 +149,37 @@ class Concept(collections.Mapping):
     A :term:`SKOS` Concept.
     '''
 
-    def __init__(self, id,
+    id = None
+    '''An id for this Concept within a vocabulary
+
+    eg. 12345
+    '''
+
+    uri = None
+    '''A proper uri for this Concept
+
+    eg. `http://id.example.com/skos/trees/1`
+    '''
+
+    type = 'concept'
+    '''The type of this concept or collection.
+
+    eg. 'concept'
+    '''
+
+    def __init__(self, id, uri=None,
                  labels=[], notes=[],
-                 broader=[], narrower=[], related=[]):
+                 broader=[], narrower=[], related=[],
+                 member_of=[]):
         self.id = id
+        self.uri = uri
+        self.type = 'concept'
         self.labels = [dict_to_label(l) for l in labels]
         self.notes = [dict_to_note(n) for n in notes]
         self.broader = broader
         self.narrower = narrower
         self.related = related
+        self.member_of = member_of
 
     def __getitem__(self, item):
         if item in self.__dict__.keys():
@@ -165,10 +208,34 @@ class Collection:
     A :term:`SKOS` Collection.
     '''
 
-    def __init__(self, id, labels=[], members=[]):
+    id = None
+    '''An id for this Collection within a vocabulary'''
+
+    uri = None
+    '''A proper uri for this Collection'''
+
+    type = 'collection'
+    '''The type of this concept or collection.
+
+    eg. 'collection'
+    '''
+
+    labels = []
+    '''A :class:`lst` of :class:`skosprovider.skos.label` instances.'''
+
+    members = []
+    '''A :class:`lst` of concept ids.'''
+
+    member_of = []
+    '''A :class:`lst` of concept or collection ids.'''
+
+    def __init__(self, id, uri=None, labels=[], members=[], member_of=[]):
         self.id = id
+        self.uri = uri
+        self.type = 'collection'
         self.labels = [dict_to_label(l) for l in labels]
         self.members = members
+        self.member_of = member_of
 
     def label(self, language='any'):
         '''
@@ -225,7 +292,7 @@ def dict_to_label(dict):
     Transform a dict with keys `label`, `type` and `language` into a
     :class:`Label`.
 
-    If the argument passed is already a :class:`Label`, this method just 
+    If the argument passed is already a :class:`Label`, this method just
     returns the argument.
     '''
     if isinstance(dict, Label):
@@ -243,14 +310,14 @@ def dict_to_note(dict):
     Transform a dict with keys `note`, `type` and `language` into a
     :class:`Note`.
 
-    If the argument passed is already a :class:`Note`, this method just returns 
+    If the argument passed is already a :class:`Note`, this method just returns
     the argument.
     '''
     if isinstance(dict, Note):
         return dict
     else:
         return Note(
-            dict['note'], 
-            dict['type'] if 'type' in dict else 'note', 
+            dict['note'],
+            dict['type'] if 'type' in dict else 'note',
             dict['language'] if 'language' in dict else None
         )
